@@ -89,11 +89,12 @@ enum Operation {
 
 impl Write for Stdout {
     fn poll_write(
-        mut self: Pin<&mut Self>,
+        self: Pin<&mut Self>,
         cx: &mut Context<'_>,
         buf: &[u8],
     ) -> Poll<io::Result<usize>> {
-        let state = &mut *self.0.lock().unwrap();
+        let mut state_guard = self.0.lock().unwrap();
+        let state = &mut *state_guard;
 
         loop {
             match state {
@@ -137,8 +138,9 @@ impl Write for Stdout {
         }
     }
 
-    fn poll_flush(mut self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<io::Result<()>> {
-        let state = &mut *self.0.lock().unwrap();
+    fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<io::Result<()>> {
+        let mut state_guard = self.0.lock().unwrap();
+        let state = &mut *state_guard;
 
         loop {
             match state {
@@ -178,6 +180,18 @@ cfg_unix! {
             std::io::stdout().as_raw_fd()
         }
     }
+
+    cfg_io_safety! {
+        use crate::os::unix::io::{AsFd, BorrowedFd};
+
+        impl AsFd for Stdout {
+            fn as_fd(&self) -> BorrowedFd<'_> {
+                unsafe {
+                    BorrowedFd::borrow_raw(std::io::stdout().as_raw_fd())
+                }
+            }
+        }
+    }
 }
 
 cfg_windows! {
@@ -188,4 +202,16 @@ cfg_windows! {
             std::io::stdout().as_raw_handle()
         }
     }
+
+    cfg_io_safety! {
+        use crate::os::windows::io::{AsHandle, BorrowedHandle};
+
+        impl AsHandle for Stdout {
+            fn as_handle(&self) -> BorrowedHandle<'_> {
+                unsafe {
+                    BorrowedHandle::borrow_raw(std::io::stdout().as_raw_handle())
+                }
+            }
+        }
+    }
 }
